@@ -63,7 +63,13 @@ class Message:
         :param message_type: Message type as returned from cdk-nag.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Message.__init__)
+            def stub(
+                *,
+                message_description: builtins.str,
+                message_type: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument message_description", value=message_description, expected_type=type_hints["message_description"])
             check_type(argname="argument message_type", value=message_type, expected_type=type_hints["message_type"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -115,7 +121,13 @@ class NagResult:
         :param resource: Resource which triggered the message.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NagResult.__init__)
+            def stub(
+                *,
+                messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
+                resource: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument messages", value=messages, expected_type=type_hints["messages"])
             check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -172,7 +184,14 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param apply_to_children: whether to apply to children.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNag.add_resource_suppressions_by_path_no_throw)
+            def stub(
+                stack: aws_cdk.Stack,
+                path: builtins.str,
+                suppressions: typing.Sequence[typing.Union[cdk_nag.NagPackSuppression, typing.Dict[str, typing.Any]]],
+                apply_to_children: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
             check_type(argname="argument suppressions", value=suppressions, expected_type=type_hints["suppressions"])
@@ -228,7 +247,9 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param stack: stack instance.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNag.get_stack_account_regex)
+            def stub(stack: aws_cdk.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackAccountRegex", [stack]))
 
@@ -240,7 +261,9 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param stack: stack instance.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNag.get_stack_partition_regex)
+            def stub(stack: aws_cdk.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPartitionRegex", [stack]))
 
@@ -254,7 +277,9 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param stack: stack instance.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNag.get_stack_prefix)
+            def stub(stack: aws_cdk.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPrefix", [stack]))
 
@@ -266,7 +291,9 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param stack: stack instance.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNag.get_stack_region_regex)
+            def stub(stack: aws_cdk.Stack) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackRegionRegex", [stack]))
 
@@ -410,7 +437,20 @@ class PDKNagAppProps(aws_cdk.AppProps):
         :inheritDoc: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PDKNagAppProps.__init__)
+            def stub(
+                *,
+                analytics_reporting: typing.Optional[builtins.bool] = None,
+                auto_synth: typing.Optional[builtins.bool] = None,
+                context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                outdir: typing.Optional[builtins.str] = None,
+                post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                stack_traces: typing.Optional[builtins.bool] = None,
+                tree_metadata: typing.Optional[builtins.bool] = None,
+                fail_on_error: typing.Optional[builtins.bool] = None,
+                fail_on_warning: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument analytics_reporting", value=analytics_reporting, expected_type=type_hints["analytics_reporting"])
             check_type(argname="argument auto_synth", value=auto_synth, expected_type=type_hints["auto_synth"])
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
